#define DEVLOCK_BATTERY_FLAGS (HW_BATTERY|HW_TEMPERATURE)
#define ALL_BATTERY_FLAGS (HW_BATTERY|HW_MEMORY|HW_CPU_USAGE|HW_CPU|HW_TEMPERATURE)

// for minimal UI, popup window and battery refresh timer
void draw_battery_widget( unsigned force, int x, int y );

// for charge animation timer
void animate_battery_widget( unsigned increment );
